"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Logger_1 = require("./Logger");
const axios_1 = require("axios");
class Api {
    _maxAttempts;
    _delayPerAttempt;
    constructor(maxAttempts, delayPerAttempt) {
        this._maxAttempts = maxAttempts;
        this._delayPerAttempt = delayPerAttempt;
    }
    async post(options, attempt) {
        Logger_1.default.log(attempt
            ? `POST *attempt[${attempt}] ${this.shortenUrl(options.url)}`
            : `POST ${this.shortenUrl(options.url)}`);
        if (attempt >= 0) {
            await this.wait(this._delayPerAttempt);
        }
        try {
            let r = await axios_1.default.post(options.url, options.payload, options.config);
            if (r.status === options.expectedStatusCode || attempt === this._maxAttempts) {
                return r;
            }
            else {
                await this.post({
                    url: options.url,
                    payload: options.payload,
                    config: options.config,
                    expectedStatusCode: options.expectedStatusCode,
                }, isNaN(attempt) ? 0 : attempt + 1);
            }
        }
        catch (e) {
            if (attempt === this._maxAttempts) {
                console.log(`${e.message} \n ${e.stack}`);
                return;
            }
            else {
                await this.post({
                    url: options.url,
                    payload: options.payload,
                    config: options.config,
                    expectedStatusCode: options.expectedStatusCode,
                }, isNaN(attempt) ? 0 : attempt + 1);
            }
        }
    }
    async put(options, attempt) {
        Logger_1.default.log(attempt
            ? `PUT *attempt[${attempt}] ${this.shortenUrl(options.url)}`
            : `PUT ${this.shortenUrl(options.url)}`);
        if (attempt > 0) {
            await this.wait(this._delayPerAttempt);
        }
        try {
            let r = await axios_1.default.put(options.url, options.payload, options.config);
            if (r.status === options.expectedStatusCode || attempt === this._maxAttempts) {
                return r;
            }
            else {
                await this.put({
                    url: options.url,
                    payload: options.payload,
                    config: options.config,
                    expectedStatusCode: options.expectedStatusCode,
                }, isNaN(attempt) ? 0 : attempt + 1);
            }
        }
        catch (e) {
            if (attempt === this._maxAttempts) {
                console.log(`${e.message} \n ${e.stack}`);
                return;
            }
            else {
                await this.put({
                    url: options.url,
                    payload: options.payload,
                    config: options.config,
                    expectedStatusCode: options.expectedStatusCode,
                }, isNaN(attempt) ? 0 : attempt + 1);
            }
        }
    }
    shortenUrl(url) {
        return url.replace(process.env.BASE_URL, '');
    }
    wait(ms) {
        return new Promise((resolve) => setTimeout(resolve, ms));
    }
}
exports.default = Api;
//# sourceMappingURL=Api.js.map